
==========================
Leonardo leonardo-celery-email
==========================

A Django email backend that uses a Celery queue for out-of-band sending of the messages.

.. contents::
    :local:

Installation
------------

.. code-block:: bash

    pip install leonardo-celery-email

Read More
=========

* https://github.com/django-leonardo/django-leonardo
